<?php

namespace forge12\contactform7\CF7Captcha;

use forge12\contactform7\CF7Captcha\core\log\Log_Item;
use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

if (!defined('ABSPATH')) {
	exit;
}

/**
 * Class AvadaMultipleSubmissionProtection
 * Validate Avada Forms
 */
class AvadaMultipleSubmissionProtection extends TimerValidatorController
{
	/**
	 * Check if multiple submission protection is enabled
	 *
	 * @return bool
	 */
	protected function isEnabled()
	{
		return (bool) CF7Captcha::getInstance()->getSettings('protect_avada_multiple_submissions', 'avada');
	}

	/**
	 * Validate spam protection
	 *
	 * @param mixed $value
	 * @return bool
	 */
	public function validateSpamProtection($value)
	{
		if (isset($_POST, $_POST['formData'])) {
			$data = ControllerAvada::formDataToArray($_POST['formData']);

			$fieldname = self::getPostFieldName();

			if (empty($data[$fieldname])) {
				/*
				 * Add Log Entries
				 */
				$logItem = new Log_Item(
					__('Avada Form - Multiple Submission Protection', 'captcha-for-contact-form-7'),
					$data,
					'spam',
					'TimerValidator failed in AvadaMultipleSubmissionProtection.class.php: Multiple submission protection field missing or empty.'
				);
				Log_WordPress::store($logItem);

				die(wp_json_encode(ControllerAvada::get_results_from_message('error', 'spam')));
			}

			$hash = sanitize_text_field($data[$fieldname]);
			$timer = TimerValidator::getInstance()->getTimer($hash);

			if (!$timer) {
				/*
				 * Add Log Entries
				 */
				$logItem = new Log_Item(
					__('Avada Form - Multiple Submission Protection', 'captcha-for-contact-form-7'),
					$data,
					'spam',
					'TimerValidator failed in AvadaMultipleSubmissionProtection.class.php: Multiple submissions detected.'
				);
				Log_WordPress::store($logItem);

				die(wp_json_encode(ControllerAvada::get_results_from_message('error', 'spam')));
			}

			$timer->delete();
		}

		return $value;
	}

	/**
	 * WordPress hook initialization
	 */
	public function onInit()
	{
		add_action('fusion_form_before_close', [$this, 'addToAvada'], 10, 2);
		add_filter('fusion_form_demo_mode', [$this, 'validateSpamProtection'], 10, 1);
	}

	/**
	 * Add timer input field to Avada forms
	 *
	 * @param mixed $args
	 * @param mixed $params
	 */
	public function addToAvada($args, $params)
	{
		echo $this->generateTimerInputField();
	}

	/**
	 * Return the validation time in milliseconds
	 *
	 * @return int
	 */
	public function getValidationTime()
	{
		return 2000;
		//return (int) CF7Captcha::getInstance()->getSettings('protect_cf7_time_ms', 'cf7');
	}

	/**
	 * Get the post field name for multiple submission protection
	 *
	 * @return string
	 */
	protected function getPostFieldName()
	{
		return 'f12_multiple_submission_protection';
	}
}
