<?php

namespace forge12\contactform7\CF7Captcha;

use forge12\contactform7\CF7Captcha\core\log\Log_Item;
use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

if (!defined('ABSPATH')) {
	exit;
}

/**
 * Class AvadaRuleValidator
 *
 * Validates Avada forms using rules
 */
class AvadaRuleValidator
{
	private static $_instance = null;

	/**
	 * Get the singleton instance of AvadaRuleValidator
	 *
	 * @return self The AvadaRuleValidator instance
	 */
	public static function getInstance()
	{
		if (self::$_instance == null) {
			self::$_instance = new AvadaRuleValidator();
		}
		return self::$_instance;
	}

	/**
	 * AvadaRuleValidator constructor.
	 * Adds the spam validation filters
	 */
	protected function __construct()
	{
		add_filter('fusion_form_demo_mode', [$this, 'isSpam'], 10, 1);
		add_filter('init', [$this, 'isSpamContactTemplate']);
	}

	/**
	 * Validate the Avada contact template for spam
	 */
	public function isSpamContactTemplate()
	{
		$form_fields = [
			'contact_name',
			'email',
			'url',
			'msg'
		];

		// Check if the form submission is present
		if (!isset($_POST['submit'])) {
			return;
		}

		// Check if all the required form fields are present
		foreach ($form_fields as $field) {
			if (!isset($_POST[$field])) {
				return;
			}
		}

		// Check each form field for spam using RulesHandler
		foreach ($form_fields as $field) {
			if (RulesHandler::getInstance()->isSpam($_POST[$field])) {
				$error_message = RulesHandler::getInstance()->getSpamMessage('', '');

				/*
				 * Add Log Entries
				 */
				$logItem = new Log_Item(
					__('Rule Validation failed', 'captcha-for-contact-form-7'),
					$_POST,
					'spam',
					'Rule Validation failed in AvadaRuleValidator.class.php: ' . $error_message
				);
				Log_WordPress::store($logItem);

				wp_die('Sorry, this mail has been blocked by spam protection: ' . $error_message);
			}
		}
	}

	/**
	 * Check if the form submission is spam
	 *
	 * @param bool $value The filter value
	 * @return mixed The validated value
	 */
	public static function isSpam($value)
	{
		/**
		 * Avada sends the form fields as formdata string.
		 */
		if (isset($_POST['formData'])) {
			$data = ControllerAvada::formDataToArray($_POST['formData']);

			// Check each form field for spam using RulesHandler
			foreach ($data as $key => $value) {
				if (RulesHandler::getInstance()->isSpam($value)) {
					$error_message = RulesHandler::getInstance()->getSpamMessage('', '');

					/*
					 * Add Log Entries
					 */
					$logItem = new Log_Item(
						__('Rule Validation failed', 'captcha-for-contact-form-7'),
						$data,
						'spam',
						'Rule Validation failed in AvadaRuleValidator.class.php: ' . $error_message
					);
					Log_WordPress::store($logItem);

					die(wp_json_encode(ControllerAvada::get_results_from_message('error', $error_message)));
				}
			}
		}

		return $value;
	}
}
