<?php

namespace forge12\contactform7\CF7Captcha;

use forge12\contactform7\CF7Captcha\core\log\Log_Item;
use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

if (!defined('ABSPATH')) {
	exit;
}

/**
 * Class Avada_Browser_Validator
 *
 * Handles browser validation for Avada forms
 */
class Avada_Browser_Validator
{
	private static $_instance = null;

	/**
	 * Get the singleton instance of Avada_Browser_Validator
	 *
	 * @return self The Avada_Browser_Validator instance
	 */
	public static function get_instance(): self
	{
		if (self::$_instance === null) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Avada_Browser_Validator constructor.
	 * Adds the spam validation filter
	 */
	private function __construct()
	{
		add_filter('fusion_form_demo_mode', [$this, 'is_spam'], 10, 1);
	}

	/**
	 * Check if the form submission is spam
	 *
	 * @param mixed $value The filter value
	 * @return mixed The validated value
	 */
	public function is_spam($value)
	{
		if (isset($_POST['formData']) && Browser::get_instance()->is_crawler()) {
			/*
			 * Add Log Entries
			 */
			$logItem = new Log_Item(
				__('Avada Form - Browser Validator', 'captcha-for-contact-form-7'),
				$_POST,
				'spam',
				'Browser validation failed in Avada_Browser_Validator.class.php'
			);
			Log_WordPress::store($logItem);

			die(wp_json_encode(ControllerAvada::get_results_from_message('error', 'spam-0')));
		}

		return $value;
	}
}
