<?php

namespace forge12\contactform7\CF7Captcha {

	use forge12\contactform7\CF7Captcha\core\log\Log_Item;
	use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class ControllerCF7
	 */
	class ControllerCF7 {
		/**
		 * Admin constructor.
		 */
		public function __construct() {
			if ( function_exists( 'wpcf7' ) ) {
				$this->init();
			}
		}

		/**
		 * @var CF7HoneypotCaptcha|null
		 */
		private $Captcha = null;

		/**
		 * @var TimerValidatorCF7|null
		 */
		private $Timer = null;

		/**
		 * @private WordPress Hook
		 */
		public function init() {
			require_once( 'Frontend.class.php' );
			$Frontend = new Frontend();

			require_once( 'Backend.class.php' );
			$Backend = new Backend();

			require_once( 'CF7RuleValidator.class.php' );
			$RuleValidator = CF7RuleValidator::getInstance();

			require_once( 'TimerValidatorCF7.class.php' );
			$this->Timer = TimerValidatorCF7::getInstance();

			require_once( 'MultipleSubmissionProtection.class.php' );
			$MultipleSubmissionProtection = MultipleSubmissionProtection::getInstance();

			if ( $this->isCaptchaEnabled() ) {
				require_once( 'CF7HoneypotCaptcha.class.php' );
				$this->Captcha = CF7HoneypotCaptcha::getInstance();

				if ( $this->is_browser_validation_enabled() ) {
					require_once( 'CF7_Browser_Validator.php' );
					CF7_Browser_Validator::get_instance();
				}

				if ( $this->is_javascript_validation_enabled() ) {
					require_once( 'CF7_Javascript_Validator.php' );
					CF7_Javascript_Validator::get_instance();
				}
			}

			if ( $this->isIPValidatorEnabled() ) {
				require_once( 'CF7IPLog.class.php' );
				$CF7IPL = CF7IPLog::getInstance();
			}

			add_action( 'wpcf7_mail_sent', [ $this, 'after_wpcf7_mail_sent' ], 10, 1 );
			add_action( 'wpcf7_mail_failed', [ $this, 'after_wpcf7_mail_sent' ], 10, 1 );
		}

		/**
		 * Add log entry that the form has been submitted
		 *
		 * @param \WPCF7_ContactForm $contact_form
		 *
		 * @return void
		 */
		public function after_wpcf7_mail_sent( $contact_form ) {
			$data = $_POST;
			/*
			 * Add Log Entries
			 */
			$Log_Item = new Log_Item(
				__( 'CF7 Form', 'captcha-for-contact-form-7' ),
				$data,
				'verified',
				'Contact Form 7 successfully committed' );
			Log_WordPress::store( $Log_Item );
		}

		private function isCaptchaEnabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect_cf7_captcha_enable', 'cf7' );
		}

		/**
		 * @return bool
		 */
		private function isIPValidatorEnabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect_ip', 'ip' );
		}

		/**
		 * @return mixed
		 */
		public static function getCaptchaMethod() {
			return CF7Captcha::getInstance()->getSettings( 'protect_cf7_method', 'cf7' );
		}

		/**
		 * Check if JavaScript Validation is enabled
		 *
		 * @return bool
		 */
		private function is_javascript_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'javascript' );
		}

		/**
		 * Check if Browser Validation is enabled
		 *
		 * @return bool
		 */
		private function is_browser_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'browser' );
		}
	}

	function validateCF7Dependencies() {
		include_once( 'cf7-notice-dependencies.php' );
	}
}