<?php

namespace forge12\contactform7\CF7Captcha {
	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class ControllerComments
	 */
	class ControllerComments {
		/**
		 * Admin constructor.
		 */
		public function __construct() {
			$this->init();
		}

		/**
		 * @private WordPress Hook
		 */
		public function init() {
			if ( $this->isCaptchaProtectionEnabled() ) {
				require_once( 'CommentValidator.class.php' );
				$CV = new CommentValidator();

				if ( $this->is_browser_validation_enabled() ) {
					require_once( 'Comment_Browser_Validator.php' );
					Comment_Browser_Validator::get_instance();
				}

				if ( $this->is_javascript_validation_enabled() ) {
					require_once( 'Comment_Javascript_Validator.php' );
					Comment_Javascript_Validator::get_instance();
				}
			}

			require_once( 'CommentRuleValidator.class.php' );
			CommentRuleValidator::getInstance();

			require_once( 'TimerValidatorComments.class.php' );
			TimerValidatorComments::getInstance();


			if ( $this->isIPValidatorEnabled() ) {
				require_once( 'CommentIPLog.class.php' );
				$IPValidator = new CommentIPLog();
			}
		}

		/**
		 * @return bool
		 */
		private function isIPValidatorEnabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect_ip', 'ip' );
		}


		/**
		 * Validate if Comment Protection is enabled
		 *
		 * @return boolean
		 */
		public function isCaptchaProtectionEnabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect_comments', 'comments' );
		}

		/**
		 * @return mixed
		 */
		public static function getCaptchaMethod() {
			return CF7Captcha::getInstance()->getSettings( 'protect_comments_method', 'comments' );
		}

		/**
		 * Check if JavaScript Validation is enabled
		 *
		 * @return bool
		 */
		private function is_javascript_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'javascript' );
		}

		/**
		 * Check if Browser Validation is enabled
		 *
		 * @return bool
		 */
		private function is_browser_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'browser' );
		}
	}
}