<?php

namespace forge12\contactform7\CF7Captcha {

	use forge12\contactform7\CF7Captcha\core\log\Log_Item;
	use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;
	use WPForms\WPForms;

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class ControllerGravityForms
	 */
	class ControllerGravityForms {
		/**
		 * Admin constructor.
		 */
		public function __construct() {

			if ( class_exists( 'GFCommon' ) ) {
				$this->init();
			}
		}

		/**
		 * @private WordPress Hook
		 */
		public function init() {
			if ( $this->isCaptchaEnabled() ) {
				require_once( 'GravityForms_Validator.php' );
				new GravityForms_Validator();

				if ( $this->is_browser_validation_enabled() ) {
					require_once( 'GravityForms_Browser_Validator.php' );
					GravityForms_Browser_Validator::get_instance();
				}

				if ( $this->is_javascript_validation_enabled() ) {
					require_once( 'GravityForms_Javascript_Validator.php' );
					GravityForms_Javascript_Validator::get_instance();
				}
			}

			require_once( 'GravityForms_Rule_Validator.php' );
			GravityForms_Rule_Validator::getInstance();

			//add_action( 'wpforms_process_complete', array( $this, 'after_validation' ), 999999999999, 4 );
		}


		public function after_validation( $fields, $entry, $form_data, $entry_id ) {
			/*
			 * Add Log Entries
			 */
			$Log_Item = new Log_Item(
				__( 'Gravity Forms Form', 'captcha-for-contact-form-7' ),
				$form_data,
				'verified',
				'Gravity Forms Form successfully committed' );
			Log_WordPress::store( $Log_Item );
		}


		/**
		 * Check if JavaScript Validation is enabled
		 *
		 * @return bool
		 */
		private function is_javascript_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'javascript' );
		}

		/**
		 * Check if Browser Validation is enabled
		 *
		 * @return bool
		 */
		private function is_browser_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'browser' );
		}

		/**
		 * @return boolean
		 */
		public function isCaptchaEnabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect_enable', 'gravity_forms' );
		}

		/**
		 * @return mixed
		 */
		public static function getCaptchaMethod() {
			return CF7Captcha::getInstance()->getSettings( 'protect_method', 'gravity_forms' );
		}
	}
}