<?php

namespace forge12\contactform7\CF7Captcha {

	use forge12\contactform7\CF7Captcha\core\log\Log_Item;
	use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class GravityForms_Validator
	 */
	class GravityForms_Validator {
		public function __construct() {
			add_filter( 'gform_get_form_filter', array( $this, 'addSpamProtection' ), 10, 2 );
			add_filter( 'gform_entry_is_spam', array( $this, 'validateSpamProtection' ), 10, 3 );
		}

		/**
		 * @return string
		 */
		private function getPostFieldName() {
			$settings = CF7Captcha::getInstance()->getSettings();

			$fieldname = 'f12_captcha';
			if ( isset( $settings['gravity_forms']['protect_fieldname'] ) ) {
				$fieldname = $settings['gravity_forms']['protect_fieldname'];
			}

			return $fieldname;
		}

		/**
		 * @return array
		 */
		public function addSpamProtection( $form_string, $form ) {
			$fieldname = $this->getPostFieldName();

			switch ( ControllerGravityForms::getCaptchaMethod() ) {
				case 'math':
					$captcha = CaptchaMathGenerator::get_form_field( $fieldname, [
						'classes'         => 'gfield gfield_contains_required',
						'wrapper_classes' => '',
						'wrapper_attributes' => ['style' => 'margin-top:15px;']
					] );
					break;
				case 'image':
					$captcha = CaptchaImageGenerator::get_form_field( $fieldname, [
						'classes'         => 'gfield gfield_contains_required',
						'wrapper_classes' => '',
						'wrapper_attributes' => ['style' => 'margin-top:15px;']
					] );
					break;
				default:
					$captcha = CaptchaHoneypotGenerator::get_form_field( $fieldname );
					break;
			}


			$form_string = str_replace("<div class='gform_footer", $captcha."<div class='gform_footer", $form_string);
			$form_string = str_replace('<div class="gform_footer', $captcha.'<div class="gform_footer', $form_string);

			return $form_string;
		}

		/**
		 * @param bool  $is_spam Indicates if the submission has been flagged as spam.
		 * @param array $form    The form currently being processed.
		 * @param array $entry   The entry currently being processed.
		 *
		 * @return array|mixed
		 */
		public function validateSpamProtection( $is_spam, $form, $entry ) {
			$fieldname = $this->getPostFieldName();

			/*
			 * Check if the fields exists
			 */
			if ( ! isset( $_POST[ $fieldname ] ) ) {

				/*
				 * Add Log Entries
				 */
				$Log_Item = new Log_Item(
					__( 'Gravity Forms Form - Captcha Validator', 'captcha-for-contact-form-7' ),
					$_POST,
					'spam',
					'Captcha failed in GravityForms_Validator.php, captcha not found.' );
				Log_WordPress::store( $Log_Item );

				return true;
			}


			/*
			 * Check if the Captcha is valid
			 */
			switch ( ControllerGravityForms::getCaptchaMethod() ) {
				case 'math':
					$isValid = CaptchaMathGenerator::validate( $_POST[ $fieldname ], $_POST[ $fieldname . '_hash' ] );
					break;
				case 'image':
					$isValid = CaptchaImageGenerator::validate( $_POST[ $fieldname ], $_POST[ $fieldname . '_hash' ] );
					break;
				default:
					$isValid = CaptchaHoneypotGenerator::validate( $_POST[ $fieldname ] );
					break;
			}

			if ( ! $isValid ) {
				/*
				 * Add Log Entries
				 */
				$Log_Item = new Log_Item(
					__( 'GravityForms Form - Captcha Validator', 'captcha-for-contact-form-7' ),
					$_POST,
					'spam',
					'Captcha validation failed in GravityForms_Validator.php' );
				Log_WordPress::store( $Log_Item );

				return true;
			}

			return $is_spam;
		}
	}
}