<?php

namespace forge12\contactform7\CF7Captcha {
	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class ControllerRegistration
	 */
	class ControllerRegistration {
		/**
		 * Constructor
		 */
		public function __construct() {
			$this->init();
		}

		/**
		 * Init all relevant functions
		 *
		 * @return void
		 */
		private function init() {
			if ( $this->isCaptchaProtectionEnabled() ) {
				require_once( 'Validator.class.php' );
				$Validator = new Validator();

				if ( $this->is_browser_validation_enabled() ) {
					require_once( 'Registration_Browser_Validator.php' );
					Registration_Browser_Validator::get_instance();
				}

				if ( $this->is_javascript_validation_enabled() ) {
					require_once( 'Registration_Javascript_Validator.php' );
					Registration_Javascript_Validator::get_instance();
				}
			}
		}

		/**
		 * Validate if Comment Protection is enabled
		 *
		 * @return boolean
		 */
		public function isCaptchaProtectionEnabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect_registration', 'wp_login_page' );
		}

		/**
		 * @return mixed
		 */
		public static function getCaptchaMethod() {
			return CF7Captcha::getInstance()->getSettings( 'protect_registration_method', 'wp_login_page' );
		}

		/**
		 * Check if JavaScript Validation is enabled
		 *
		 * @return bool
		 */
		private function is_javascript_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'javascript' );
		}

		/**
		 * Check if Browser Validation is enabled
		 *
		 * @return bool
		 */
		private function is_browser_validation_enabled() {
			return (bool) CF7Captcha::getInstance()->getSettings( 'protect', 'browser' );
		}
	}
}