<?php

namespace forge12\contactform7\CF7Captcha {

	use forge12\contactform7\CF7Captcha\core\log\Log_Item;
	use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class Javascript Validator
	 * Responsible to handle the frontend of the Double OptIn
	 *
	 * @package forge12\contactform7\CF7Captcha
	 */
	class UltimateMember_Javascript_Validator {
		private static $_instance = null;

		private $has_been_checked = false;

		public static function get_instance(): UltimateMember_Javascript_Validator {
			if ( self::$_instance == null ) {
				self::$_instance = new UltimateMember_Javascript_Validator();
			}

			return self::$_instance;
		}

		/**
		 * Admin constructor.
		 */
		private function __construct() {
			add_action( 'um_add_error_on_form_submit_validation', [ $this, 'is_spam' ], 10, 3 );
		}

		/**
		 * Get the Post Field Name from the settings.
		 *
		 * @return mixed|string
		 */
		protected function getPostFieldName() {
			$settings = CF7Captcha::getInstance()->getSettings();

			$fieldname = 'f12_captcha';
			if ( isset( $settings['ultimatemember']['protect_fieldname'] ) ) {
				$fieldname = $settings['ultimatemember']['protect_fieldname'];
			}

			return $fieldname;
		}

		public function is_spam( $fields, $field, $args ) {
			if($this->has_been_checked){
				return;
			}

			$this->has_been_checked = true;

			$is_spam = ! Timer::get_instance()->is_human();

			if ( $is_spam ) {

				$fieldname = $this->getPostFieldName();

				/*
				 * Add Log Entries
				 */
				$Log_Item = new Log_Item(
					__( 'Ultimate Member Form - Javascript Validator Log', 'captcha-for-contact-form-7' ),
					$_POST,
					'spam',
					'Javascript validation failed in UltimateMember_Browser_Validator.php' );
				Log_WordPress::store( $Log_Item );

				UM()->form()->add_error( $fieldname, __( 'You have been identified as spam, please try again later.', 'captcha-for-contact-form-7' ) );
			}

			return $is_spam;
		}
	}
}