<?php

namespace forge12\contactform7\CF7Captcha {

	use forge12\contactform7\CF7Captcha\core\log\Log_Item;
	use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class WPForms_Rule_Validator
	 */
	class WPForms_Rule_Validator {
		private static $_instance = null;

		public static function getInstance() {
			if ( self::$_instance == null ) {
				self::$_instance = new WPForms_Rule_Validator();
			}

			return self::$_instance;
		}


		protected function __construct() {
			add_action( 'wpforms_process_initial_errors', array( $this, 'is_spam' ), 10, 2 );
		}

		/**
		 * @param bool              $spam
		 * @param \WPCF7_Submission $submission
		 *
		 * @return mixed|void
		 */
		public static function is_spam( $errors, $form_data ) {
			if ( ! isset( $form_data['fields'] ) ) {
				return $errors;
			}

			if ( ! isset( $form_data['id'] ) ) {
				return $errors;
			}

			$form_id = $form_data['id'];

			foreach ( $form_data['fields'] as $key => $form_field ) {
				if ( ! isset( $_POST['wpforms']['fields'][$form_field['id']]) ) {
					continue;
				}

				$form_value = $_POST['wpforms']['fields'][$form_field['id']];

				if(is_array($form_value)){
					foreach($form_value as $key => $value){
						if ( RulesHandler::getInstance()->isSpam( $value ) ) {
							$error_message = RulesHandler::getInstance()->getSpamMessage( '', '' );
							/*
							 * Add Log Entries
							 */
							$Log_Item = new Log_Item(
								__( 'Rule Validation failed', 'captcha-for-contact-form-7' ),
								$_POST,
								'spam',
								'Rule Validation failed in WPForms_Rule_Validator.class.php: ' . $error_message );
							Log_WordPress::store( $Log_Item );

							$errors[ $form_id ]['footer'] = sprintf( esc_html__( 'Rule Validation failed: %s', 'captcha-for-contact-form-7' ), $error_message );
						}
					}
				}else{
					if ( RulesHandler::getInstance()->isSpam( $form_value ) ) {
						$error_message = RulesHandler::getInstance()->getSpamMessage( '', '' );

						/*
						 * Add Log Entries
						 */
						$Log_Item = new Log_Item(
							__( 'Rule Validation failed', 'captcha-for-contact-form-7' ),
							$_POST,
							'spam',
							'Rule Validation failed in WPForms_Rule_Validator.class.php: ' . $error_message );
						Log_WordPress::store( $Log_Item );

						$errors[ $form_id ]['footer'] = sprintf( esc_html__( 'Rule Validation failed: %s', 'captcha-for-contact-form-7' ), $error_message );
					}
				}
			}
			return $errors;
		}
	}
}