<?php

namespace forge12\contactform7\CF7Captcha {

	use forge12\contactform7\CF7Captcha\core\log\Log_Item;
	use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class WPFormsValidator
	 */
	class WPForms_Validator {
		public function __construct() {
			add_action( 'wpforms_frontend_output', array( $this, 'addSpamProtection' ), 10, 5 );
			add_action( 'wpforms_process_initial_errors', array( $this, 'validateSpamProtection' ), 10, 2 );
		}

		/**
		 * @return string
		 */
		private function getPostFieldName() {
			$settings = CF7Captcha::getInstance()->getSettings();

			$fieldname = 'f12_captcha';
			if ( isset( $settings['wpforms']['protect_fieldname'] ) ) {
				$fieldname = $settings['wpforms']['protect_fieldname'];
			}

			return $fieldname;
		}

		/**
		 * @param $form_data
		 * @param $deprecated
		 * @param $title
		 * @param $description
		 * @param $errors
		 *
		 * @return array
		 */
		public function addSpamProtection( $form_data, $deprecated, $title, $description, $errors ) {
			$settings  = CF7Captcha::getInstance()->getSettings();
			$fieldname = $this->getPostFieldName();

			switch ( ControllerWPForms::getCaptchaMethod() ) {
				case 'math':
					$captcha = CaptchaMathGenerator::get_form_field( $fieldname, [
						'classes'         => 'wpforms-field-medium wpforms-field-required',
						'wrapper_classes' => 'wpforms-field'
					] );
					break;
				case 'image':
					$captcha = CaptchaImageGenerator::get_form_field( $fieldname, [
						'classes'         => 'wpforms-field-medium wpforms-field-required',
						'wrapper_classes' => 'wpforms-field'
					] );
					break;
				default:
					$captcha = CaptchaHoneypotGenerator::get_form_field( $fieldname );
					break;
			}

			echo $captcha;
		}

		public function validateSpamProtection( $errors, $form_data ) {
			$fieldname = $this->getPostFieldName();

			if(!isset($form_data['id'])){
				return $errors;
			}

			$form_id = $form_data['id'];
			/*
			 * Check if the fields exists
			 */
			if ( ! isset( $_POST[ $fieldname ] ) ) {

				/*
				 * Add Log Entries
				 */
				$Log_Item = new Log_Item(
					__( 'WPForms Form - Captcha Validator', 'captcha-for-contact-form-7' ),
					$_POST,
					'spam',
					'Captcha failed in WPFormsValidator.php, captcha not found.' );
				Log_WordPress::store( $Log_Item );

				$errors[ $form_id ]['footer'] = esc_html__( 'Captcha validation failed, captcha not found.', 'captcha-for-contact-form-7' );
				return $errors;
			}


			/*
			 * Check if the Captcha is valid
			 */
			switch ( ControllerWPForms::getCaptchaMethod() ) {
				case 'math':
					$isValid = CaptchaMathGenerator::validate( $_POST[ $fieldname ], $_POST[ $fieldname . '_hash' ] );
					break;
				case 'image':
					$isValid = CaptchaImageGenerator::validate( $_POST[ $fieldname ], $_POST[ $fieldname . '_hash' ] );
					break;
				default:
					$isValid = CaptchaHoneypotGenerator::validate( $_POST[ $fieldname ] );
					break;
			}

			if ( ! $isValid ) {

				/*
				 * Add Log Entries
				 */
				$Log_Item = new Log_Item(
					__( 'WPForms Form - Captcha Validator', 'captcha-for-contact-form-7' ),
					$_POST,
					'spam',
					'Captcha validation failed in WPFormsValidator.php' );
				Log_WordPress::store( $Log_Item );

				$errors[ $form_id ]['footer'] = esc_html__( 'Captcha validation failed.', 'captcha-for-contact-form-7' );
				return $errors;
			}

			return $errors;
		}
	}
}