<?php

namespace forge12\contactform7\CF7Captcha {
	class Browser {
		private $browser_names = [];
		private $browser_regexes = [];
		private $platform_names = [];
		private $platform_regexes = [];
		private $device_type_names = [];
		private $device_type_regexes = [];

		/**
		 * @var Browser|null
		 */
		private static $_instance = null;

		public static function get_instance(): Browser {
			if ( self::$_instance == null ) {
				self::$_instance = new Browser();
			}

			return self::$_instance;
		}

		private function __construct() {
			require( 'Browser_User_Agent.php' );

			$this->browser_names       = $browser_names;
			$this->browser_regexes     = $browser_regexes;
			$this->platform_names      = $platform_names;
			$this->platform_regexes    = $platform_regexes;
			$this->device_type_names   = $device_type_names;
			$this->device_type_regexes = $device_type_regexes;
		}

		public static function get_user_agent(): string {
			if(!isset($_SERVER['HTTP_USER_AGENT'])){
				return '';
			}
			return $_SERVER['HTTP_USER_AGENT'];
		}

		public function is_default( $browser_data ) {
			$default_browser_data = [
				'browser_name'     => '',
				'browser_version'  => '',
				'platform_name'    => '',
				'device_type_name' => '',
				'is_mobile'        => false,
			];

			return empty( array_diff_assoc( $browser_data, $default_browser_data ) );
		}

		public function get_headers_as_string():string{
			$header_data = $this->get_headers();

			$response = '';
			foreach ( $header_data as $key => $value ) {
				$response .= $key . ':' . $value . ',';
			}

			return $response;
		}

		public function get_headers(): array {
			if(function_exists('getallheaders')) {
				$headers = getallheaders();
			}else{
				$headers = [];
			}

			$required_headers = array(
				'Accept',
				'Accept-Charset',
				'Accept-Encoding',
				'Accept-Language',
				'Connection',
				//'Host',
				//'Referer',
				'User-Agent',
			);

			$header_data = [];

			foreach ( $required_headers as $header ) {
				if ( isset( $headers[ $header ] ) ) {
					// The header is missing
					// Handle the missing header as needed
					$header_data[$header] = $headers[ $header ];
				}
			}

			return $header_data;
		}

		public function get_browser_as_string(): string {
			$browser_data = $this->get_browser();

			$response = '';
			foreach ( $browser_data as $key => $value ) {
				$response .= $key . ':' . $value . ',';
			}

			return $response;
		}

		public function get_browser( $user_agent = '' ): array {
			if ( empty( $user_agent ) ) {
				$user_agent = self::get_user_agent();
			}

			$browser_data = [
				'browser_name'     => '',
				'browser_version'  => '',
				'platform_name'    => '',
				'device_type_name' => '',
				'is_mobile'        => false,
			];

			foreach ( $this->browser_regexes as $index => $regex ) {
				if ( preg_match( $regex, $user_agent, $matches ) ) {
					$browser_data['browser_name']    = $this->browser_names[ $index ];
					$browser_data['browser_version'] = ( isset( $matches[3] ) ? $matches[3] : isset( $matches[2] ) ) ? $matches[2] : '';

					foreach ( $this->platform_regexes as $index => $regex ) {
						if ( preg_match( $regex, $user_agent, $matches ) ) {
							$browser_data['platform_name'] = $this->platform_names[ $index ];
							break;
						}
					}

					foreach ( $this->device_type_regexes as $index => $regex ) {
						if ( preg_match( $regex, $user_agent, $matches ) ) {
							$browser_data['device_type_name'] = $this->device_type_names[ $index ];
							break;
						}
					}

					if ( preg_match( '/Mobile/i', $user_agent ) ) {
						$browser_data['is_mobile'] = true;
					}

					break;
				}
			}

			return $browser_data;
		}

		/**
		 * Determine if the current call is done by a bot.
		 *
		 * @param $user_agent
		 *
		 * @return bool
		 */
		private function is_bot( $user_agent = '' ) {
			if ( empty( $user_agent ) ) {
				$user_agent = self::get_user_agent();
			}

			if ( preg_match( '/bot|crawl|slurp|spider/i', $user_agent ) ) {
				return true;
			}

			return false;
		}

		/**
		 * Determine if the current call is done by a crawler
		 *
		 * @return bool|void
		 */
		public function is_crawler(): bool {
			$browser_data = $this->get_browser();

			if ( $this->is_default( $browser_data ) || $this->is_bot() ) {
				return true;
			}

			return false;
		}
	}
}