<?php

namespace forge12\contactform7\CF7Captcha {
	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	/**
	 * Class CaptchaImageGenerator
	 * Generate the custom captcha as an image
	 *
	 * @package forge12\contactform7
	 */
	class CaptchaImageGenerator extends CaptchaGenerator {
		/**
		 * @var string The font used for the captcha
		 */
		private $_font = '';

		/**
		 * constructor.
		 */
		public function __construct( $length ) {
			parent::__construct( $length );

			$this->_font = plugin_dir_path( __FILE__ ) . 'assets/arial.ttf';
		}

		/**
		 * Generate the Captcha
		 */
		public function getImage() {
			// the captcha
			$captcha = $this->get();

			// Create the image
			$image = imagecreate( 125, 30 );
			imagecolorallocate( $image, 255, 255, 255 );

			// Positioning
			$offsetLeft = 10;

			for ( $i = 0; $i < strlen( $captcha ); $i ++ ) {
				imagettftext( $image, 20, rand( - 10, 10 ), $offsetLeft + ( ( $i == 0 ? 5 : 15 ) * $i ), 25, imagecolorallocate( $image, 200, 200, 200 ), $this->_font, $captcha[ $i ] );
				imagettftext( $image, 16, rand( - 15, 15 ), $offsetLeft + ( ( $i == 0 ? 5 : 15 ) * $i ), 25, imagecolorallocate( $image, 69, 103, 137 ), $this->_font, $captcha[ $i ] );
			}

			ob_start();
			imagepng( $image );
			$image = ob_get_contents();
			ob_end_clean();

			return '<span class="captcha-image"><img src="data:image/png;base64,' . base64_encode( $image ) . '"/></span>';
		}

		public static function validate( $captcha_code, $captcha_hash ) {
			$Captcha = Captcha::getByHash( $captcha_hash );

			if(!$Captcha || $Captcha->getValidated() == 1){
				return false;
			}

			$Captcha->setValidated(1);
			$Captcha->save();

			if ($captcha_code != $Captcha->getCode() ) {
				return false;
			}

			return true;
		}

		/**
		 * @param $fieldname
		 * @param $args [] [
		 *              'classes'         => '',
		 *              'wrapper_classes' => '',
		 *              'attributes'      => []
		 *              ]
		 *
		 * @return mixed|null
		 */
		public static function get_form_field( $fieldname, $args = [] ) {
			$atts = [
				'classes'            => '',
				'wrapper_classes'    => '',
				'attributes'         => [],
				'wrapper_attributes' => [],
			];

			$atts = array_merge( $atts, $args );

			$Captcha     = new CaptchaImageGenerator( 6 );
			$CaptchaItem = __( 'Captcha:', 'captcha-for-contact-form-7' ) . ' ' . $Captcha->getImage() . ' ' . $Captcha->getReloadButton();

			$CaptchaSession = new Captcha();
			$CaptchaSession->setCode( $Captcha->get() );
			$CaptchaSession->save();

			$attributes = '';

			foreach ( $atts['attributes'] as $key => $value ) {
				$attributes .= esc_attr( $key ) . '="' . esc_attr( $value ) . '"';
			}

			$wrapper_attributes = '';
			foreach ( $atts['wrapper_attributes'] as $key => $value ) {
				$wrapper_attributes .= esc_attr( $key ) . '="' . esc_attr( $value ) . '"';
			}

			$captcha = parent::get_additional_form_fields();
			$captcha .= '<input type="hidden" id="' . esc_attr( $fieldname ) . '_hash" name="' . esc_attr( $fieldname ) . '_hash" value="' . esc_attr( $CaptchaSession->getHash() ) . '" />';
			$captcha .= '<div class="' . $atts['wrapper_classes'] . '" ' . $wrapper_attributes . '><label > ' . $CaptchaItem . '</label ><input class="f12c ' . $atts['classes'] . '" data-method = "image" ' . $attributes . ' type="text" id="' . esc_attr( $fieldname ) . '" name="' . esc_attr( $fieldname ) . '" placeholder="' . __( 'Captcha', 'captcha-for-contact-form-7' ) . '" value = "" /></div > ';

			return apply_filters( 'f12-cf7-captcha-get-form-field-image', $captcha, $fieldname, $CaptchaItem, $CaptchaSession, $atts['classes'] );
		}
	}
}