<?php

namespace forge12\contactform7\CF7Captcha {

	class Timer {

		/**
		 * @var array<string => float>
		 */
		private $start_time = [
			'php' => 0.0,
			'js'  => 0.0
		];

		/**
		 * @var array <string => float>
		 */
		private $end_time = [
			'php' => 0.0,
			'js'  => 0.0
		];

		/**
		 * @var Timer|null
		 */
		private static $_instance = null;

		public static function get_instance(): Timer {
			if ( self::$_instance == null ) {
				self::$_instance = new Timer();
			}

			return self::$_instance;
		}

		private function __construct() {
			$this->init_php();
			$this->init_js();
		}

		private function init_js() {
			$start = 0.0;
			$end   = 0.0;

			if ( isset( $_POST['js_start_time'] ) && isset( $_POST['js_end_time'] ) ) {
				$start = (float) $_POST['js_start_time'];
				$end   = (float) $_POST['js_end_time'];
			}

			// Avada
			if ( isset( $_POST['formData'] ) ) {
				parse_str( wp_unslash( $_POST['formData'] ), $form_data );

				if ( isset( $form_data['js_start_time'] ) && isset( $form_data['js_end_time'] ) ) {
					$start = (float) $form_data['js_start_time'];
					$end   = (float) $form_data['js_end_time'];
				}
			}

			$this->set_start_time( 'js', $start );
			$this->set_end_time( 'js', $end );
		}

		/**
		 * @param string $type php or js
		 * @param float  $microtime
		 *
		 * @return void
		 */
		private function set_start_time( string $type, float $microtime ) {

			$this->start_time[ $type ] = $microtime;
		}

		/**
		 * @param string $type php or js
		 * @param float  $microtime
		 *
		 * @return void
		 */
		private function set_end_time( string $type, float $microtime ) {
			$this->end_time[ $type ] = $microtime;
		}

		private function init_php() {
			$start = 0.0;

			// CF7, Discussions ...
			if ( isset( $_POST['php_start_time'] ) ) {
				$start = (float) $_POST['php_start_time'];
			}

			// Avada
			if ( isset( $_POST['formData'] ) ) {
				parse_str( wp_unslash( $_POST['formData'] ), $form_data );

				if ( isset( $form_data['php_start_time'] ) ) {
					$start = (float) $form_data['php_start_time'];
				}
			}

			$this->set_start_time( 'php', $start );

			if ( $start != 0.0 ) {
				$this->set_end_time( 'php', microtime( true ) );
			}
		}

		public function get_form_field(): string {
			$additional_fields = [
				'<input type="hidden" name="php_start_time" value="' . microtime( true ) . '" />',
				'<input type="hidden" name="js_end_time" class="js_end_time" value="" />',
				'<input type="hidden" name="js_start_time" class="js_start_time" value="" />'
			];

			return implode( "", $additional_fields );
		}

		public function get_start_time( $type = 'php' ): float {
			return $this->start_time[ $type ];
		}

		public function get_end_time( $type = 'php' ): float {
			return $this->end_time[ $type ];
		}

		/**
		 * @param string $type   php or js
		 * @param string $output ms for milliseconds, s for seconds
		 *
		 * @return string
		 */
		public function get_difference( string $type = 'php', string $output = 'ms' ): string {
			$difference = $this->get_end_time( $type ) - $this->get_start_time( $type );

			if ( $output == 'ms' ) {
				return round( $difference * 1000 );
			} else {
				return round( $difference );
			}

			return '0';
		}

		public function get_timer_as_string( string $type = 'php' ): string {
			$data = [
				'Form loaded'    => date( 'd.m.Y H:i:s', $this->get_start_time( $type ) ) . ' [' . $this->get_start_time( $type ) . ']',
				'Form submitted' => date( 'd.m.Y H:i:s', $this->get_end_time( $type ) ) . ' [' . $this->get_end_time( $type ) . ']',
				'Time passed'    => $this->get_difference( $type ) . ' ms, ' . $this->get_difference( $type, 's' ) . ' sec',
			];

			$response = '';
			foreach ( $data as $key => $value ) {
				$response .= $key . ': ' . $value . ',';
			}

			return $response;
		}

		/**
		 * Check if the user is a human.
		 *
		 * @return bool
		 */
		public function is_human(): bool {
			if ( $this->get_difference( 'js' ) == 0 || $this->get_difference( 'js' ) == '0.0' ) {
				return false;
			}

			if ( $this->get_start_time( 'js' ) == 0.0 ) {
				return false;
			}

			if ( $this->get_end_time( 'js' ) == 0.0 ) {
				return false;
			}

			return true;
		}
	}
}